==> admob-4.4.0-sources.jar: com/yodo1/mas/mediation/admob/Yodo1MasAdaptersPrivacy.java <==
package com.yodo1.mas.mediation.admob;

import android.app.Activity;

import java.lang.reflect.Method;

public class Yodo1MasAdaptersPrivacy {

    public static void setAdColonyPrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.adcolony.Yodo1MasAdColonyAdapter");
            Method m = clz.getMethod("setAdColonyPrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setAppLovinPrivacy(Activity activity) {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.applovin.Yodo1MasAppLovinAdapter");
            Method m = clz.getMethod("setAppLoinPrivacy", Activity.class);
            m.invoke(clz.newInstance(), activity);
        } catch (Exception e) {

        }
    }

    public static void setFacebookPrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.facebook.Yodo1MasFacebookAdapter");
            Method m = clz.getMethod("setFacebookPrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setFyberPrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.fyber.Yodo1MasFyberAdapter");
            Method m = clz.getMethod("setFyberPrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setInMobiPrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.inmobi.Yodo1MasInMobiAdapter");
            Method m = clz.getMethod("setInMobiPrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setIronSourcePrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.ironsource.Yodo1MasIronSourceAdapter");
            Method m = clz.getMethod("setIronSourcePrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setMyTargetPrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.mytarget.Yodo1MasMyTargetAdapter");
            Method m = clz.getMethod("setMyTargetPrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setTapjoyPrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.tapjoy.Yodo1MasTapjoyAdapter");
            Method m = clz.getMethod("setTapjoyPrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setUnityAdsPrivacy(Activity activity) {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.unityads.Yodo1MasUnityAdsAdapter");
            Method m = clz.getMethod("setUnityAdsPrivacy", Activity.class);
            m.invoke(clz.newInstance(), activity);
        } catch (Exception e) {

        }
    }

    public static void setVunglePrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.vungle.Yodo1MasVungleAdapter");
            Method m = clz.getMethod("setVunglePrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }
}

==> admob-4.8.5-sources.jar: com/yodo1/mas/mediation/admob/Yodo1MasAdaptersPrivacy.java <==
package com.yodo1.mas.mediation.admob;

import android.content.Context;

import androidx.annotation.NonNull;

import java.lang.reflect.Method;

public class Yodo1MasAdaptersPrivacy {

    public static void setAdColonyPrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.adcolony.Yodo1MasAdColonyAdapter");
            Method m = clz.getMethod("setAdColonyPrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setAppLovinPrivacy(@NonNull Context context) {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.applovin.Yodo1MasAppLovinAdapter");
            Method m = clz.getMethod("setAppLoinPrivacy", Context.class);
            m.invoke(clz.newInstance(), context);
        } catch (Exception e) {

        }
    }

    public static void setFacebookPrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.facebook.Yodo1MasFacebookAdapter");
            Method m = clz.getMethod("setFacebookPrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setFyberPrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.fyber.Yodo1MasFyberAdapter");
            Method m = clz.getMethod("setFyberPrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setInMobiPrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.inmobi.Yodo1MasInMobiAdapter");
            Method m = clz.getMethod("setInMobiPrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setIronSourcePrivacy(@NonNull Context context) {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.ironsource.Yodo1MasIronSourceAdapter");
            Method m = clz.getMethod("setIronSourcePrivacy", Context.class);
            m.invoke(clz.newInstance(), context);
        } catch (Exception e) {

        }
    }

    public static void setMyTargetPrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.mytarget.Yodo1MasMyTargetAdapter");
            Method m = clz.getMethod("setMyTargetPrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setTapjoyPrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.tapjoy.Yodo1MasTapjoyAdapter");
            Method m = clz.getMethod("setTapjoyPrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }

    public static void setUnityAdsPrivacy(@NonNull Context context) {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.unityads.Yodo1MasUnityAdsAdapter");
            Method m = clz.getMethod("setUnityAdsPrivacy", Context.class);
            m.invoke(clz.newInstance(), context);
        } catch (Exception e) {

        }
    }

    public static void setVunglePrivacy() {
        try {
            Class clz = Class.forName("com.yodo1.mas.mediation.vungle.Yodo1MasVungleAdapter");
            Method m = clz.getMethod("setVunglePrivacy");
            m.invoke(clz.newInstance());
        } catch (Exception e) {

        }
    }
}
